<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Core\Author
 * @copyright   Copyright (c) 2019, WeCodeArt Framework
 * @since		3.7.7
 * @version		3.9.5
 */

namespace WeCodeArt\Core;

defined( 'ABSPATH' ) || exit();

use WeCodeArt\Utilities\Markup;

/**
 * Adds some output to archive pages
 */
class Author {

	use \WeCodeArt\Singleton;

	/**
	 * Do author box on archive
	 *
	 * @since	3.7.7
	 * @version	3.9.5
	 */
	public function author_box_archive() {
		$enabled = apply_filters( 'wecodeart/filter/author/box/archive/enabled', '__return_true' );

		if ( ! $enabled || ( ! is_author() || get_query_var( 'paged' ) >= 2 ) ) {
			return;
		}

		self::render_box();
	}

	/**
	 * Do author box on single
	 *
	 * @since	3.7.7
	 * @version	3.9.5
	 */
	public function author_box_single() {
		$enabled = apply_filters( 'wecodeart/filter/author/box/single/enabled', '__return_true' );

		if ( ! $enabled || ( ! is_single() || ! post_type_supports( get_post_type(), 'author' ) ) ) {
			return;
		}

		self::render_box();
	}

	/**
	 * Echo the Author Box
	 *
	 * @since	3.7.7
	 * @version 3.9.5
	 *
	 * @return 	void 
	 */
	public static function render_box() {
		$enabled = apply_filters( 'wecodeart/filter/author/box/enabled', '__return_true' );

		if( ! $enabled || ! self::get_data() ) return;

		Markup::template( 'entry/author/box', self::get_data() );
	}

	/**
	 * Get Author Information
	 *
	 * @since 	3.9.1
	 * @version	3.9.5
	 *
	 * @return 	array 
	 */
	public static function get_data() {
		$avatar_size = apply_filters( 'wecodeart/filter/author/box/gravatar_size', 100 );
		$avatar_alt  = sprintf( esc_html__( "%s's gravatar", wecodeart_config( 'textdomain' ) ), get_the_author() );

		$author = [
			'intro' 		=> is_author() ? esc_html__( 'All articles by', wecodeart_config( 'textdomain' ) ) : esc_html__( 'About', wecodeart_config( 'textdomain' ) ),
			'name'			=> get_the_author(),
			'avatar' 		=> get_avatar( get_the_author_meta( 'email' ), $avatar_size, '', $avatar_alt ),
			'description'	=> wpautop( get_the_author_meta( 'description' ) ),
			'url'			=> get_author_posts_url( get_the_author_meta( 'ID' ) ),
			'container' 	=> ! is_single() ? get_theme_mod( 'content-layout-container' ) : 'container-full'
		];

		if ( 0 === mb_strlen( $author['name'] ) || 0 === mb_strlen( $author['description'] ) ) {
			return [];
		}

		if ( is_singular() ) {
			$author['name']	= sprintf( 
				'<a href="%s" rel="author nofollow">%s</a>', 
				esc_url( $author['url'] ), esc_html( $author['name'] ) 
			);
		}

		return $author;
	} 
}