<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Loops
 * @copyright   Copyright (c) 2019, WeCodeArt Framework
 * @since		3.5
 * @version		3.9.5
 */ 

namespace WeCodeArt\Core;

defined( 'ABSPATH' ) || exit();

use WeCodeArt\Core\Entry;
use WeCodeArt\Utilities\Markup;

/**
 * Loops
 */
class Loops {

	use \WeCodeArt\Singleton;

	/**
	 * Standard WP Loop, meant to be executed anywhere needed in templates.
	 *
	 * @since	1.0
	 * @version	3.9.5
	 *
	 * @return 	void
	 */
	public static function default() {
		global $wp_query;

		do_action( 'wecodeart/hook/loop/before' );
		
		// The WordPress Loop.
		if( have_posts() ) :

			do_action( 'wecodeart/hook/loop/while/before' );

			while( have_posts() ) : the_post();

				$post_id 	= get_the_ID();
				$index 		= $wp_query->current_post;
				
				do_action( 'wecodeart/hook/loop/entry/before', $post_id, $index );

				/**
				 * Entry Hook
				 * 
				 * @see 	WeCodeArt\Utilities\Markup::wrap()
				 * @see		do_action(); WP Function
				 * @hook	'wecodeart_entry' 	
				 * @hooked 	{
				 * - WeCodeArt\Core\Entry->render_header()	- 20 Entry Header Hook
				 * - WeCodeArt\Core\Entry->render_content()	- 30 Entry Content Hook 
				 * - WeCodeArt\Core\Entry->render_footer()	- 40 Entry Footer Hook
				 * }
				 */
				Markup::wrap( 'entry', [ [
					'tag' 	=> 'article',
					'attrs' => [
						'id' 	=> get_post_type() . '-' . $post_id, 
						'class'	=> implode( ' ', get_post_class() ) 
					]
				] ], 'do_action', [ 'wecodeart_entry', $post_id, $index  ] );

				do_action( 'wecodeart/hook/loop/entry/after', $post_id, $index );

			endwhile; // end of one post.

			do_action( 'wecodeart/hook/loop/while/after' );

		else : // if no posts exist.

			do_action( 'wecodeart/hook/loop/else' );

		endif; // end loop.

		do_action( 'wecodeart/hook/loop/after' );
	}
}