<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Customizer\Configs
 * @copyright   Copyright (c) 2019, WeCodeArt Framework
 * @since 		3.5
 * @version		3.7.3
 */

namespace WeCodeArt\Customizer;

defined( 'ABSPATH' ) || exit;

use WeCodeArt\Customizer\Config;

/**
 * Customizer Configs Panel/Sections
 */
class Configs extends Config {
	/**
	 * Register Site Layout Customizer Configurations
	 *
	 * @param 	array                $configurations 
	 * @param 	WP_Customize_Manager $wp_customize instance of WP_Customize_Manager.
	 * @since 	3.6
	 *
	 * @return 	array 
	 */
	public function register( $configurations, $wp_customize ) {
		$configs = array(
			/**
			 * Header 
			 */
			array(
				'name'     => 'header',
				'type'     => 'panel',
				'priority' => 5,
				'title'    => esc_html__( 'Header Settings', 'wecodeart' ) 
			),
			array(
				'name'     => 'header-bar',
				'type'     => 'section',
				'priority' => 5,
				'title'    => esc_html__( 'Header Bar', 'wecodeart' ),
				'panel'    => 'header',
			),
			/**
			 * Content
			 */
			array(
				'name'     => 'content',
				'type'     => 'panel',
				'priority' => 10,
				'title'    => esc_html__( 'Content Settings', 'wecodeart' ) 
			),
			array(
				'name'     => 'content-layout',
				'type'     => 'section',
				'priority' => 5,
				'title'    => esc_html__( 'Layout Settings', 'wecodeart' ),
				'panel'    => 'content',
			),
			array(
				'name'     => 'content-entry',
				'type'     => 'section',
				'priority' => 10,
				'title'    => esc_html__( 'Entry Settings', 'wecodeart' ),
				'panel'    => 'content',
			),
			/**
			 * Footer
			 */
			array(
				'name'     => 'footer',
				'type'     => 'panel',
				'priority' => 15,
				'title'    => esc_html__( 'Footer Settings', 'wecodeart' ) 
			),
			array(
				'name'     => 'footer-layout',
				'type'     => 'section',
				'priority' => 5,
				'title'    => esc_html__( 'Layout Settings', 'wecodeart' ),
				'panel'    => 'footer',
			),
			array(
				'name'     => 'footer-copyright',
				'type'     => 'section',
				'priority' => 10,
				'title'    => esc_html__( 'Copyright', 'wecodeart' ),
				'panel'    => 'footer',
			)
		);

		return array_merge( $configurations, $configs );
	}
}
