<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Customizer\Controls\Divider
 * @copyright   Copyright (c) 2019, WeCodeArt Framework
 * @since 		3.8.5
 * @version		3.9.5
 */

namespace WeCodeArt\Customizer\Controls;

defined( 'ABSPATH' ) || exit;

use WP_Customize_Control;

if ( class_exists( 'WeCodeArt\Customizer\Controls\Divider' ) ) return NULL;

/**
 * Simple divider control that only displays some content.
 */
class Divider extends WP_Customize_Control {

	use \WeCodeArt\Core\Scripts\Base;

	/**
	 * The control type.
	 *
	 * @access  public
	 * @var     string
	 */
	public $type = 'wecodeart-divider';

	/**
	 * The control type.
	 *
	 * @access  public
	 * @var     string
	 */
	public $caption = '';

	/**
	 * The control type.
	 *
	 * @access public
	 * @var string
	 */
	public $separator = true;

	/**
	 * Enqueue control related scripts/styles.
	 *
	 * @access public
	 *
	 * @since 	unknown
	 * @version	3.9.5
	 */
	public function enqueue() {

		wp_enqueue_style( $this->make_handle(), $this->get_asset( 'css', 'divider' ), [], wecodeart( 'version' ) );

	}

	/**
	 * Refresh the parameters passed to the JavaScript via JSON.
	 *
	 * @see WP_Customize_Control::to_json()
	 */
	public function to_json() {
		parent::to_json();
		$this->json['label']       = esc_html( $this->label );
		$this->json['caption']     = $this->caption;
		$this->json['description'] = $this->description;
		$this->json['separator']   = $this->separator;
	}

	/**
	 * An Underscore (JS) template for this control's content (but not its container).
	 *
	 * Class variables for this control class are available in the `data` JS object;
	 * export custom variables by overriding {@see WP_Customize_Control::to_json()}.
	 *
	 * @see WP_Customize_Control::print_template()
	 *
	 * @access protected
	 */
	protected function content_template() {
		?>

		<# if ( data.caption ) { #>
			<span class="customize-control-caption">{{{ data.caption }}}</span>
		<# } #>

		<# if ( data.separator == true || data.separator.top == true ) { #>
			<hr />
		<# } #>

		<div class="customize-control-wecodeart-divider__wrapper">
			<label class="customizer-text">
				<# if ( data.label ) { #>
					<span class="customize-control-title">{{{ data.label }}}</span>
				<# } #>
				<# if ( data.description ) { #>
					<span class="description customize-control-description">{{{ data.description }}}</span>
				<# } #>
			</label>
		</div>

		<# if ( data.separator == true || data.separator.bottom == true ) { #>
			<hr />
		<# } #>

		<?php
	}
}
